import { joinUser, taskFile, getViewLogList } from '@/api/table'
import { getToken } from '@/utils/auth'

const user = {
  state: {
    uid: getToken(),
    joinUserList: [],
    fileList: [],
    logList: []
  },

  mutations: {
    SET_JOINUSERLIST: (state, list) => {
      state.joinUserList = list
    },
    SET_FILELIST: (state, data) => {
      state.fileList = [...data.localFile, ...data.screenshot]
    },
    SET_LOGLIST: (state, data) => {
      state.logList = data.list
    }
  },

  actions: {
    // 获取参会人员
    JoinUser({ commit, state }) {
      return new Promise((resolve, reject) => {
        joinUser(getToken()).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data.list)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取参会文件
    TaskFile({ commit }, taskId) {
      return new Promise((resolve, reject) => {
        taskFile(taskId).then(response => {
          console.log(response)
          const data = response.data
          commit('SET_FILELIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取浏览信息
    GetViewLogList({ commit }, pageNo, pageSize) {
      return new Promise((resolve, reject) => {
        getViewLogList(pageNo, pageSize).then(response => {
          const data = response.data
          commit('SET_LOGLIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
